@@ -6,7 +6,7 @@ from logging import getLogger, DEBUG
 from re import sub
 
 from requests import get, Response, post
-from spotipy import SpotifyOAuth
+from spotipy import SpotifyOAuth, CacheFileHandler
 
 from wg_utilities.loggers import add_stream_handler
 
@@ -294,6 +294,7 @@ class SpotifyClient:
         scope (list): either a list of scopes or comma separated string of scopes.
         oauth_manager (SpotifyOAuth): an already-instantiated OAuth manager which
          provides authentication for all API interactions
+        creds_cache_path (str): path at which to save cached credentials
     """
 
     BASE_URL = "https://api.spotify.com/v1"
@@ -330,12 +331,14 @@ class SpotifyClient:
         scope=None,
         oauth_manager=None,
         log_requests=False,
+        creds_cache_path=None,
     ):
         self.oauth_manager = oauth_manager or SpotifyOAuth(
             client_id=client_id,
             client_secret=client_secret,
             redirect_uri=redirect_uri,
             scope=scope,
+            cache_handler=CacheFileHandler(cache_path=creds_cache_path),
         )
         self.log_requests = log_requests
         self.api_call_count = 0
@@ -521,6 +524,51 @@ class SpotifyClient:
 
         return self._current_user
 
+    def add_tracks_to_playlist(self, tracks, playlist):
+        """Add one or more tracks to a playlist
+
+        Args:
+            tracks (list): a list of Track instances to be added to the given playlist
+            playlist (Playlist): the playlist being updated
+
+        Returns:
+            Response: the response from the web API
+        """
+
+        res = self._post(
+            f"/playlists/{playlist.id}/tracks", json={"uris": [t.uri for t in tracks]}
+        )
+
+        res.raise_for_status()
+
+        return res
+
+    def create_playlist(self, name, description="", public=False, collaborative=False):
+        """Create a new playlist under the current user's account
+
+        Args:
+            name (str): the name of the new playlist
+            description (str): the description of the new playlist
+            public (bool): determines if the playlist is publicly accessible
+            collaborative (bool): allows other people to add tracks when True
+
+        Returns:
+            Playlist: an instance of the Playlist class containing the new playlist's
+             metadata
+        """
+
+        res = self._post(
+            f"/users/{self.current_user.id}/playlists",
+            {
+                "name": name,
+                "description": description,
+                "public": public,
+                "collaborative": collaborative,
+            },
+        )
+
+        return Playlist(res.json(), self)
+
     def get_playlists_by_name(self, name, return_all=False):
         """Gets Playlist instance(s) which have the given name
 
@@ -623,22 +671,3 @@ class SpotifyClient:
             Track(item.get("track", {}), self, metadata={"liked_at": item["added_at"]})
             for item in self.get_items_from_url("/me/tracks", **kwargs)
         ]
-
-    def add_tracks_to_playlist(self, tracks, playlist):
-        """Add one or more tracks to a playlist
-
-        Args:
-            tracks (list): a list of Track instances to be added to the given playlist
-            playlist (Playlist): the playlist being updated
-
-        Returns:
-            Response: the response from the web API
-        """
-
-        res = self._post(
-            f"/playlists/{playlist.id}/tracks", json={"uris": [t.uri for t in tracks]}
-        )
-
-        res.raise_for_status()
-
-        return res
